<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Devices.Display.Core

Windows Runtime (WinRT) APIs for for the `Windows.Devices.Display.Core` namespace.

This package provides the `winrt.windows.devices.display.core` module.
